<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Loopback</name>
    <message>
        <location filename="loopback.cpp" line="133"/>
        <source>This plugin provides DMX loopback. Data written to each output is forwarded to the respective input.</source>
        <translation>The plugin offre une possibilite de bouclage DMX. Les données qui rentrent dans chaque entrée ressortent inchangées par la sortie correspondante.</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="146"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="149"/>
        <location filename="loopback.cpp" line="171"/>
        <source>Status: Used</source>
        <translation>Status : utilisée</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="152"/>
        <location filename="loopback.cpp" line="174"/>
        <source>Status: Not used</source>
        <translation>Status : non utilisée</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="168"/>
        <source>Input</source>
        <translation>Sortie</translation>
    </message>
</context>
</TS>
